@@ -372,6 +372,17 @@ class Database(object):
         query.exec_()
         self.db.commit()
 
+    def removeRoutineExercise(self, re_id):
+        query = QSqlQuery()
+        
+        query.prepare("""DELETE FROM routine_exercises
+                         WHERE re_id=?""")
+
+        query.addBindValue(re_id)
+
+        query.exec_()
+        self.db.commit()
+
     def getRow(self, field, value):
         query = QSqlQuery()
         if field == 't_name':
@@ -411,6 +422,5 @@ class Database(object):
 
         return query.value(0).toInt()[0] - 1
 
-
 if __name__ == '__main__':
     Database()
