@@ -21,7 +21,7 @@
 # pyqt modules
 from PyQt4.QtGui import (QApplication, QFileDialog, QStandardItem,
                          QStandardItemModel, QWizard)
-from PyQt4.QtCore import (pyqtSignature, Qt, pyqtSignal)
+from PyQt4.QtCore import (pyqtSignature, Qt, pyqtSignal, SIGNAL)
 from PyQt4.QtMaemo5 import (QMaemo5ListPickSelector, QMaemo5ValueButton)
 import sip
 
@@ -32,8 +32,6 @@ import config as c
 from ui.ui_exercise_wizard import Ui_ExerciseWizard
 
 class ExerciseWizard(QWizard, Ui_ExerciseWizard):
-    #TODO: enforce referential integrety (required fields, etc)
-
     exercisesUpdated = pyqtSignal()
 
     def __init__(self, parent=None, database=None, old_name=None):
@@ -45,46 +43,53 @@ class ExerciseWizard(QWizard, Ui_ExerciseWizard):
         self.setupValueButtons()
         self.loadConfigOptions()
         self.reflowWidgets()
+        self.registerFields()
 
         self.accepted.connect(self.updateExercises)
-
         QApplication.desktop().resized.connect(self.reflowWidgets)
 
+    def registerFields(self):
+        self.setDefaultProperty('QMaemo5ValueButton', 'checked',
+                                SIGNAL('clicked(bool)'))
+        self.name_and_description_page.registerField('name*',
+                                                     self.name_line_edit)
 
     def setupValueButtons(self):
         self.target_area_selector = QMaemo5ListPickSelector()
         self.target_area_selector.setModel(self.db.target_areas_model)
-        self.target_area_selector.setModelColumn(1)
-        self.target_area_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
-        self.target_area_value_button.setPickSelector(self.target_area_selector)
+        self.characteristics_page.target_area_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
+        self.characteristics_page.target_area_value_button.setPickSelector(self.target_area_selector)
 
         self.frequency_selector = QMaemo5ListPickSelector()
         self.frequency_selector.setModel(self.db.frequencies_model)
-        self.frequency_selector.setModelColumn(1)
-        self.frequency_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
-        self.frequency_value_button.setPickSelector(self.frequency_selector)
+        self.characteristics_page.frequency_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
+        self.characteristics_page.frequency_value_button.setPickSelector(self.frequency_selector)
         
         self.frequency_selector.selected.connect(self.updateSelectors)
 
         self.duration_selector = QMaemo5ListPickSelector()
         self.duration_selector.setModel(self.db.durations_model)
-        self.duration_selector.setModelColumn(1)
-        self.duration_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
-        self.duration_value_button.setPickSelector(self.duration_selector)
+        self.characteristics_page.duration_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
+        self.characteristics_page.duration_value_button.setPickSelector(self.duration_selector)
 
         self.intensity_selector = QMaemo5ListPickSelector()
         self.intensity_selector.setModel(self.db.intensities_model)
-        self.intensity_selector.setModelColumn(1)
-        self.intensity_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
-        self.intensity_value_button.setPickSelector(self.intensity_selector)
+        self.characteristics_page.intensity_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
+        self.characteristics_page.intensity_value_button.setPickSelector(self.intensity_selector)
 
         self.equipment_selector = QMaemo5ListPickSelector()
         self.equipment_selector.setModel(self.db.equipment_model)
-        self.equipment_selector.setModelColumn(1)
-        # None
+
         self.equipment_selector.setCurrentIndex(5)
-        self.equipment_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
-        self.equipment_value_button.setPickSelector(self.equipment_selector)
+        self.characteristics_page.equipment_value_button.setValueLayout(QMaemo5ValueButton.ValueBesideText)
+        self.characteristics_page.equipment_value_button.setPickSelector(self.equipment_selector)
+
+        for selector in (self.target_area_selector, self.frequency_selector,
+                         self.duration_selector, self.intensity_selector,
+                         self.equipment_selector):
+            selector.setModelColumn(1)
+            selector.selected.connect(self.characteristics_page.completeChanged)
+            
 
     def updateExercises(self):
         ex_name = self.name_line_edit.text()
